"""Version information for NoLess."""

__version__ = "0.2.1a1"
__title__ = "NoLess"
__description__ = "AI-powered ML project generation with local LLMs"
__author__ = "NoLess Team"
__license__ = "MIT"
__copyright__ = "Copyright 2024 NoLess Team"

VERSION_INFO = {
    "version": __version__,
    "name": __title__,
    "description": __description__,
    "features": [
        "Multi-agent automation",
        "LLM-powered code generation",
        "Dataset discovery & search",
        "Code validation & optimization",
        "Iterative refinement",
        "Performance optimization",
        "Advanced accuracy improvements"
    ]
}
